============
Installation
============

At the command line::

    $ pip install horizon-bsn

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv horizon-bsn
    $ pip install horizon-bsn
